Learn R Programming

DESP (version 0.2)

DESP_MST_MaxDegreeRoot: MST computation

Description

This function computes the minimum spanning trees, choosing the root of each tree as the node of maximal degree of the connected component.

Usage

DESP_MST_MaxDegreeRoot(Graph)

Arguments

Graph
The considered graph.

Value

DESP_MST_MaxDegreeRoot returns a list with components:
penult
The vector containing the preceding node on the spanning tree for each node of the graph. The root of a spanning tree is considered to be preceded by itself.
cc
The list of the connected components of the given graph.

References

Kruskal, J. B. Jr. (1956): On the shortest spanning subtree of a graph and the traveling salesman problem, Proc. Amer. Math. Soc., 7, 48--50.

See Also

connComp, mstree.kruskal