DESP_PEN_grad: Steepest descent algorithm for penalized maximum likelihood estimation
Description
This function implements the steepest descent algorithm with adaptative stepsize and scaled descent direction to solve the maximum likelihood optimization problem and get the inverse of the diagonal of the precision matrix.Usage
DESP_PEN_grad(S, B, init, kappa, thresh, stepsize, tol)
Arguments
S
The sample covariance matrix.
init
The starting vector of the iteration.
kappa
The tunning paramater.
thresh
The threshold level.
stepsize
The initial step-size.
tol
The gradient magnitude tolerance.
Value
- This function returns the inverse of the diagonal of the precision matrix associated with the sample covariance matrix S as a vector.