DESP_Weighted_Graph: Graph representation from the matrix B
Description
This function build a weighted undirected graph without loops from the matrix B. The weights of the edges depend on squared partial correlations.Usage
DESP_Weighted_Graph(B, n)
Value
- A new undirected graphNEL object.