Learn R Programming

DESP (version 0.1-2)

DESP-package: Estimation of Diagonal Elements of Sparse Precision-Matrices

Description

This package provides several methods of estimation of the diagonal elements of a sparse precision matrix. It also includes functions for estimating the off-diagonal elements of the latter by the square-root Lasso.

Arguments

Details

ll{ Package: DESP Type: Package Version: 0.1 Date: 2015-05-25 License: GPL-3 } [object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object]

References

Balmand, S. and Dalalyan, A. S. (2015): On estimation of the diagonal elements of a sparse precision matrix, Posted as http://arxiv.org/abs/1504.04696.

See Also

mosek,gurobi,scsSOCP, connComp, mstree.kruskal, dijkstra.sp