Learn R Programming

DESP (version 0.2)

DESP-package: Estimation of Diagonal Elements of Sparse Precision-Matrices

Description

This package provides several methods of estimation of the diagonal elements of a sparse precision matrix. It also includes functions for estimating robustly the off-diagonal elements of the latter by the square-root Lasso.

Arguments

Details

Package:
DESP
Type:
Package
Version:
0.1-5
Date:
2015-11-18
License:
GPL-3
DESP_RV
Estimation of DESP by residual variance

DESP_RML
Estimation of DESP by likelihood maximization

DESP_SPT
Estimation of DESP using shortest path trees

DESP_MST
Estimation of DESP using minimum spanning trees

DESP_PML
Estimation of DESP by penalized likelihood minimization

sqR_Lasso
Solve the square-root LASSO

scsSOCP
Solve a second-order cone program using SCS

precMat
Robust estimation of a sparse precision matrix

References

Balmand, S. and Dalalyan, A. S. (2015a): On estimation of the diagonal elements of a sparse precision matrix, Posted as http://arxiv.org/abs/1504.04696.

Balmand, S. and Dalalyan, A. S. (2015b): Convex programming approach to robust estimation of a multivariate Gaussian model, Posted as http://arxiv.org/abs/1512.04734.

See Also

mosek,gurobi,scsSOCP, connComp, mstree.kruskal, dijkstra.sp