Learn R Programming

DESP (version 0.2)

DESP_SPT_MaxDegreeRoot: SPT computation choosing root a priori as the node of maximal degree

Description

This function computes the shortest path tree of each connected component choosing root a priori as the node of maximal degree.

Usage

DESP_SPT_MaxDegreeRoot(Graph)

Arguments

Graph
The undirected weighted graph.

Value

DESP_SPT_MaxDegreeRoot returns a list with components:
penult
The vector containing the preceding node on the shortest path tree for each node of the graph. The root of a shortest path tree is considered to be preceded by itself.
cc
The list of the connected components of the given graph.

References

Dijkstra, E. W. (1959): A note on two problems in connexion with graphs, Numer. Math., 1, 269--271.

See Also

dijkstra.sp