Learn R Programming

DESP (version 0.2)

DESP_SPT_MaxWeight: Maximum weighted tree among all shortest path trees computation

Description

This function selects the maximum weighted tree among all shortest path trees, for each connected components of the given graph.

Usage

DESP_SPT_MaxWeight(Graph)

Arguments

Graph
The considered graph.

Value

DESP_SPT_MaxWeight returns a list with components:
penult
The vector containing the preceding node on the shortest path tree for each node of the graph. The root of a spanning tree is considered to be preceded by itself.
cc
The list of the connected components of the given graph.

References

Dijkstra, E. W. (1959): A note on two problems in connexion with graphs, Numer. Math., 1, 269--271.

See Also

dijkstra.sp