model
The model representing the convex problem to solve is a list containing the components that follow. The sparse matrix A is stored using the compressed sparse column (CSC) format.
[object Object],[object Object],[object Object],[object Object],[object